﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using MindFusion.UI.WinForms;

namespace CookBook
{
    public partial class Form1 : Form
    {
        DockItem titleItem;
        DockItem imageItem;
        DockItem ingredientsItem;
        DockItem preparationItem;
        ListView recipesListView; 
        List<Recipe> recipes;
        Recipe selectedRecipe;
        TextBox tb;
        DataGridView grid;
        PictureBox pictureBox;

        public Form1()
        {
            InitializeComponent();

            recipes = new List<Recipe>(3);
        
            Ingredient flour = new Ingredient("flour", "../../images/flour.png");
            Ingredient sugar = new Ingredient("sugar", "../../images/sugar.png");
            Ingredient baking_powder = new Ingredient("baking powder", "../../images/baking_powder.png");
            Ingredient baking_soda = new Ingredient("baking soda", "../../images/baking_soda.png");
            Ingredient cocoa = new Ingredient("cocoa", "../../images/cocoa.png");
            Ingredient egg = new Ingredient("egg", "../../images/egg.png");
            Ingredient vanilla = new Ingredient("vanilla", "../../images/vanilla.png");
            Ingredient milk = new Ingredient("milk", "../../images/milk.png");
            Ingredient ginger = new Ingredient("ginger", "../../images/ginger.png");
            Ingredient butter = new Ingredient("butter", "../../images/butter.png");
        

            Recipe chocolateCake = new Recipe("Chocolate Cake");
            chocolateCake.ImageUrl = "../../images/chocolate_cake.jpg";
            chocolateCake.IconUrl = "../../images/cake_icon.png";
            flour.Quantity = "3/4 cup";
            sugar.Quantity = "1 cup";
            cocoa.Quantity = "1 teaspoon";
            baking_powder.Quantity = "1 teaspoon";
            baking_soda.Quantity = "1/2 teaspoon";
            milk.Quantity = "1 cup";
            vanilla.Quantity = "1 small packet";
            egg.Quantity = "2";

            List<Ingredient> cakeIngredients = new List<Ingredient>()
            {
                flour,
                sugar,
                egg,
                cocoa,
                baking_powder,
                baking_soda,
                vanilla,
                milk
            };
            chocolateCake.Ingredients = cakeIngredients;
            chocolateCake.Preparation = "Mix the sugar, flour, cocoa, baking powder, baking soda in a large bowl. Add the eggs, the milk" + 
            " and the vanilla. Beat with a mixer until texture is smooth. Pour the mixture into a greasy pan. Bake 30 to 35 minutes " + 
            " until a wooden stick inserted in the center comes out clean. Do not open the oven the first 30 minutes to check!";

            recipes.Add(chocolateCake);
            selectedRecipe = chocolateCake;

            Recipe cupcakes = new Recipe("Cupcakes");
            cupcakes.ImageUrl = "../../images/cupcakes.jpg";
            cupcakes.IconUrl = "../../images/cupcake_icon.png";
            flour.Quantity = "2 cups";
            sugar.Quantity = "2 cups";           
            baking_soda.Quantity = "2 teaspoons";
            vanilla.Quantity = "2 teaspoons";
            ginger.Quantity = "1/3 cup finely chopped";
            egg.Quantity = "4";
            butter.Quantity = "1 cup";

            List<Ingredient> cupcakeIngredients = new List<Ingredient>()
            {
                flour,
                sugar,
                egg,  
                ginger,       
                baking_soda,
                vanilla,
                butter
            };
            cupcakes.Ingredients = cupcakeIngredients;
            cupcakes.Preparation = "Mix together the flour, the baking soda and the ginger in a deep bowl. " +
                "Beat the butter with the sugar using a mixer until sugar is dissolved. Add the eggs one at a time, stir manually. Add the butter " +
                " bit by bit. Finally beat in the vanilla dissolved with the last egg. Stir in the flour mixture and mix until smooth. " +
                "Pour the batter into the prepared muffin cups. Bake in a preheated oven at 350 degrees F (175 degrees C) for about 20 minutes.";

            recipes.Add(cupcakes);

            Recipe cookies = new Recipe("Cookies");
            cookies.ImageUrl = "../../images/cookies.jpg";
            cookies.IconUrl = "../../images/cookies_icon.png";
            flour.Quantity = "2 3/4 cups";
            sugar.Quantity = "2 cups";
            baking_soda.Quantity = "1 teaspoon";
            vanilla.Quantity = "2 teaspoons";          
            egg.Quantity = "2";
            butter.Quantity = "1 1/4 cup";

            List<Ingredient> cookiesIngredients = new List<Ingredient>()
            {
                flour,
                sugar,
                egg,                      
                baking_soda,
                vanilla,
                butter
            };
            cookies.Ingredients = cookiesIngredients;
            cookies.Preparation = " Stir together the flour and the baking soda. Set aside. Beat together the butter and the sugar until light " +
                "and fluffy. Beat in the eggs one at a time, then the vanilla. Gradually add the dry ingredients, stir by hand until blended. " +
                " Spread the dough and cut circles with en empty glass or a cookie form. Place the cookies slightly apart. " +
                "Bake in a preheated oven at 350 degrees F (175 degrees C) for about 8-10 minutes.";

            recipes.Add(cookies);

            titleItem = new DockItem() { Header = "Recipe Name", Id = "Name" };
            titleItem.DockStyle = DockStyle.Left;      
            titleItem.Content = GetContent("Name");

            imageItem = new DockItem() { Header = "Recipe Image", Id = "Image" };
            imageItem.DockStyle = DockStyle.Fill;
            imageItem.Content = GetContent("Image");

            ingredientsItem = new DockItem() { Header = "Ingredients", Id = "Ingredients" };
            ingredientsItem.DockStyle = DockStyle.Bottom;
            ingredientsItem.Content = GetContent("Ingredients");

            preparationItem = new DockItem() { Header = "Preparation", Id = "Preparation" };
            preparationItem.DockStyle = DockStyle.Right;
            preparationItem.Content = GetContent("Preparation");

            dockControl1.Items.Add(titleItem);
            dockControl1.Items.Add(imageItem);
            dockControl1.Items.Add(ingredientsItem);
            dockControl1.Items.Add(preparationItem);

        }

        private Control GetContent(string contentType)
        {
            Control control = null;
            if (contentType == "Name")
            {
                // Create a new ListView control.
                recipesListView = new ListView();
                recipesListView.HideSelection = false;
                recipesListView.MultiSelect = false;
                recipesListView.BackColor = Color.FromArgb(245, 245, 245);

                // Create two ImageList objects.
                ImageList imageListSmall = new ImageList();
                ImageList imageListLarge = new ImageList();

                //Assign the ImageList objects to the ListView.
                recipesListView.LargeImageList = imageListLarge;
                recipesListView.SmallImageList = imageListSmall;

                // Set the view to show details.
                recipesListView.View = View.List;
                // Create three items and three sets of subitems for each item.
                int counter = 0;

                foreach (Recipe r in recipes)
                {
                    imageListLarge.Images.Add(Bitmap.FromFile(r.IconUrl));
                    imageListSmall.Images.Add(Bitmap.FromFile(r.IconUrl));
                    ListViewItem item = new ListViewItem(r.Title, counter);
                    recipesListView.Items.Add(item);
                    counter++;
                }

                recipesListView.SelectedIndexChanged += new EventHandler(recipesListView_SelectedIndexChanged);
                control = recipesListView;
            }
            else if (contentType == "Ingredients")
            {                
                grid = new DataGridView();
                grid.DefaultCellStyle.BackColor = Color.FromArgb(247, 226, 189);
                grid.Dock = DockStyle.Fill;
                grid.MultiSelect = false;
                grid.DataSource = selectedRecipe.Ingredients;
                grid.RowTemplate.MinimumHeight = 35;
            
                grid.RowHeadersWidthSizeMode =
            DataGridViewRowHeadersWidthSizeMode.DisableResizing;
                grid.ColumnHeadersHeightSizeMode = DataGridViewColumnHeadersHeightSizeMode.DisableResizing;
                grid.AutoSizeColumnsMode = DataGridViewAutoSizeColumnsMode.Fill;
                grid.SelectionMode = DataGridViewSelectionMode.FullRowSelect;
                grid.BackgroundColor = Color.FromArgb(253, 244, 247);

                control = grid; 
            }
            else if (contentType == "Image")
            {                
                pictureBox = new PictureBox();              

                // Stretches the image to fit the pictureBox.
                pictureBox.SizeMode = PictureBoxSizeMode.Zoom;
                pictureBox.BackColor = Color.FromArgb(251, 232, 240);
                pictureBox.ClientSize = imageItem.Size;
                pictureBox.Image = Image.FromFile(selectedRecipe.ImageUrl);
                control = pictureBox;

            }

            else if (contentType == "Preparation")
            {               
               
                tb = new TextBox();
                tb.BackColor = Color.FromArgb(235, 255, 236);
                tb.Multiline = true;
                tb.WordWrap = true;
                tb.Text = selectedRecipe.Preparation;
                tb.Margin = new System.Windows.Forms.Padding(5);

                control = tb;

            }
            
            return control;
        }

        void recipesListView_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (recipesListView.SelectedIndices.Count > 0)
            {
                selectedRecipe = recipes[recipesListView.SelectedIndices[0]];
                tb.Text = selectedRecipe.Preparation;
                grid.DataSource = selectedRecipe.Ingredients;
                pictureBox.Image = Image.FromFile(selectedRecipe.ImageUrl);
            }

        }
    }
}
